@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "virtual-ring" "0.1"
+(define-package "virtual-ring" "20250920.1541"
   "Fixed size rings with virtual rotation."
   '((emacs "25.1"))
   :url "https://github.com/countvajhula/virtual-ring"
-  :commit "ded8cf97a234d2e9bf5bdaa405aca20659e0d40d"
-  :revdesc "v0.1-0-gded8cf97a234"
+  :commit "2d53ba23ecdca94801cc88085c7df7346d98e514"
+  :revdesc "2d53ba23ecdc"
   :authors '(("Sid Kasivajhula" . "sid@countvajhula.com"))
   :maintainers '(("Sid Kasivajhula" . "sid@countvajhula.com")))
